@@ -6,13 +6,6 @@ from glob import glob
 from pathlib import Path
 
 
-class DummyNotifier:
-
-    @classmethod
-    def notify(message):
-        ...
-
-
 def is_time_str(s: str) -> bool:
     if s == "":
         return False
